Package: phosphoricons
Title: 'Phosphor' Icons for R
Version: 0.2.1
Authors@R: 
    c(person(given = "Victor",
             family = "Perrier",
             role = c("aut", "cre", "cph"),
             email = "victor.perrier@dreamrs.fr"),
      person(given = "Fanny",
             family = "Meyer",
             role = "aut"),
      person(given = "Phosphor Icons",
             role = "cph",
             comment = "Phosphor Icons <https://github.com/phosphor-icons>"))
Description: Use 'Phosphor' icons in 'shiny' applications or 'rmarkdown' documents. Icons are available in
    5 different weights and can be customized by setting color, size, orientation and more.
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.3.1
Depends: R (>= 2.10)
Imports: htmltools (>= 0.3)
Suggests: covr, shiny, tinytest
URL: https://dreamrs.github.io/phosphoricons/,
        https://github.com/dreamRs/phosphoricons
BugReports: https://github.com/dreamRs/phosphoricons/issues
NeedsCompilation: no
Packaged: 2024-04-08 05:45:05 UTC; perri
Author: Victor Perrier [aut, cre, cph],
  Fanny Meyer [aut],
  Phosphor Icons [cph] (Phosphor Icons
    <https://github.com/phosphor-icons>)
Maintainer: Victor Perrier <victor.perrier@dreamrs.fr>
Repository: CRAN
Date/Publication: 2024-04-08 06:12:59 UTC
Built: R 4.6.0; ; 2026-04-27 07:08:53 UTC; unix
